@@ -56,73 +56,73 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Wiznet5k.git"
 # pylint: disable=bad-whitespace
 
 # Wiznet5k Registers
-REG_MR             = const(0x0000) # Mode
-REG_GAR            = const(0x0001) # Gateway IP Address
-REG_SUBR           = const(0x0005) # Subnet Mask Address
-REG_VERSIONR_W5500 = const(0x0039) # W5500 Silicon Version
-REG_SHAR           = const(0x0009) # Source Hardware Address
-REG_SIPR           = const(0x000F) # Source IP Address
-REG_PHYCFGR        = const(0x002E) # W5500 PHY Configuration
+REG_MR = const(0x0000)  # Mode
+REG_GAR = const(0x0001)  # Gateway IP Address
+REG_SUBR = const(0x0005)  # Subnet Mask Address
+REG_VERSIONR_W5500 = const(0x0039)  # W5500 Silicon Version
+REG_SHAR = const(0x0009)  # Source Hardware Address
+REG_SIPR = const(0x000F)  # Source IP Address
+REG_PHYCFGR = const(0x002E)  # W5500 PHY Configuration
 
 # Wiznet5k Socket Registers
-REG_SNMR           = const(0x0000) # Socket n Mode
-REG_SNCR           = const(0x0001) # Socket n Command
-REG_SNIR           = const(0x0002) # Socket n Interrupt
-REG_SNSR           = const(0x0003) # Socket n Status
-REG_SNPORT         = const(0x0004) # Socket n Source Port
-REG_SNDIPR         = const(0x000C) # Destination IP Address
-REG_SNDPORT        = const(0x0010) # Destination Port
-REG_SNRX_RSR       = const(0x0026) # RX Free Size
-REG_SNRX_RD        = const(0x0028) # Read Size Pointer
-REG_SNTX_FSR       = const(0x0020) # Socket n TX Free Size
-REG_SNTX_WR        = const(0x0024) # TX Write Pointer
+REG_SNMR = const(0x0000)  # Socket n Mode
+REG_SNCR = const(0x0001)  # Socket n Command
+REG_SNIR = const(0x0002)  # Socket n Interrupt
+REG_SNSR = const(0x0003)  # Socket n Status
+REG_SNPORT = const(0x0004)  # Socket n Source Port
+REG_SNDIPR = const(0x000C)  # Destination IP Address
+REG_SNDPORT = const(0x0010)  # Destination Port
+REG_SNRX_RSR = const(0x0026)  # RX Free Size
+REG_SNRX_RD = const(0x0028)  # Read Size Pointer
+REG_SNTX_FSR = const(0x0020)  # Socket n TX Free Size
+REG_SNTX_WR = const(0x0024)  # TX Write Pointer
 
 # SNSR Commands
-SNSR_SOCK_CLOSED      = const(0x00)
-SNSR_SOCK_INIT        = const(0x13)
-SNSR_SOCK_LISTEN      = const(0x14)
-SNSR_SOCK_SYNSENT     = const(0x15)
-SNSR_SOCK_SYNRECV     = const(0x16)
+SNSR_SOCK_CLOSED = const(0x00)
+SNSR_SOCK_INIT = const(0x13)
+SNSR_SOCK_LISTEN = const(0x14)
+SNSR_SOCK_SYNSENT = const(0x15)
+SNSR_SOCK_SYNRECV = const(0x16)
 SNSR_SOCK_ESTABLISHED = const(0x17)
-SNSR_SOCK_FIN_WAIT    = const(0x18)
-SNSR_SOCK_CLOSING     = const(0x1A)
-SNSR_SOCK_TIME_WAIT   = const(0x1B)
-SNSR_SOCK_CLOSE_WAIT  = const(0x1C)
-SNSR_SOCK_LAST_ACK    = const(0x1D)
-SNSR_SOCK_UDP         = const(0x22)
-SNSR_SOCK_IPRAW       = const(0x32)
-SNSR_SOCK_MACRAW      = const(0x42)
-SNSR_SOCK_PPPOE       = const(0x5F)
+SNSR_SOCK_FIN_WAIT = const(0x18)
+SNSR_SOCK_CLOSING = const(0x1A)
+SNSR_SOCK_TIME_WAIT = const(0x1B)
+SNSR_SOCK_CLOSE_WAIT = const(0x1C)
+SNSR_SOCK_LAST_ACK = const(0x1D)
+SNSR_SOCK_UDP = const(0x22)
+SNSR_SOCK_IPRAW = const(0x32)
+SNSR_SOCK_MACRAW = const(0x42)
+SNSR_SOCK_PPPOE = const(0x5F)
 
 # Sock Commands (CMD)
-CMD_SOCK_OPEN      = const(0x01)
-CMD_SOCK_LISTEN    = const(0x02)
-CMD_SOCK_CONNECT   = const(0x04)
-CMD_SOCK_DISCON    = const(0x08)
-CMD_SOCK_CLOSE     = const(0x10)
-CMD_SOCK_SEND      = const(0x20)
-CMD_SOCK_SEND_MAC  = const(0x21)
+CMD_SOCK_OPEN = const(0x01)
+CMD_SOCK_LISTEN = const(0x02)
+CMD_SOCK_CONNECT = const(0x04)
+CMD_SOCK_DISCON = const(0x08)
+CMD_SOCK_CLOSE = const(0x10)
+CMD_SOCK_SEND = const(0x20)
+CMD_SOCK_SEND_MAC = const(0x21)
 CMD_SOCK_SEND_KEEP = const(0x22)
-CMD_SOCK_RECV      = const(0x40)
+CMD_SOCK_RECV = const(0x40)
 
 # Socket n Interrupt Register
 SNIR_SEND_OK = const(0x10)
 SNIR_TIMEOUT = const(0x08)
-SNIR_RECV    = const(0x04)
-SNIR_DISCON  = const(0x02)
-SNIR_CON     = const(0x01)
+SNIR_RECV = const(0x04)
+SNIR_DISCON = const(0x02)
+SNIR_CON = const(0x01)
 
-CH_SIZE     = const(0x100)
-SOCK_SIZE   = const(0x800) # MAX W5k socket size
+CH_SIZE = const(0x100)
+SOCK_SIZE = const(0x800)  # MAX W5k socket size
 # Register commands
-MR_RST      = const(0x80) # Mode Register RST
+MR_RST = const(0x80)  # Mode Register RST
 # Socket mode register
-SNMR_CLOSE  = const(0x00)
-SNMR_TCP    = const(0x21)
-SNMR_UDP    = const(0x02)
-SNMR_IPRAW  = const(0x03)
+SNMR_CLOSE = const(0x00)
+SNMR_TCP = const(0x21)
+SNMR_UDP = const(0x02)
+SNMR_IPRAW = const(0x03)
 SNMR_MACRAW = const(0x04)
-SNMR_PPPOE  = const(0x05)
+SNMR_PPPOE = const(0x05)
 
 # pylint: enable=bad-whitespace
 MAX_PACKET = const(4000)
@@ -134,11 +134,10 @@ DEFAULT_MAC = (0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED)
 W5200_W5500_MAX_SOCK_NUM = const(0x08)
 
 # UDP socket struct.
-UDP_SOCK = {'bytes_remaining': 0,
-            'remote_ip': 0,
-            'remote_port': 0}
+UDP_SOCK = {"bytes_remaining": 0, "remote_ip": 0, "remote_port": 0}
 
-class WIZNET5K: # pylint: disable=too-many-public-methods
+
+class WIZNET5K:  # pylint: disable=too-many-public-methods
     """Interface for WIZNET5K module.
     :param ~busio.SPI spi_bus: The SPI bus the Wiznet module is connected to.
     :param ~digitalio.DigitalInOut cs: Chip select pin.
@@ -151,16 +150,15 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
 
     TCP_MODE = const(0x21)
     UDP_MODE = const(0x02)
-    TLS_MODE = const(0x03) # This is NOT currently implemented
+    TLS_MODE = const(0x03)  # This is NOT currently implemented
 
     # pylint: disable=too-many-arguments
-    def __init__(self, spi_bus, cs, reset=None,
-                 is_dhcp=True, mac=DEFAULT_MAC, debug=False):
+    def __init__(
+        self, spi_bus, cs, reset=None, is_dhcp=True, mac=DEFAULT_MAC, debug=False
+    ):
         self._debug = debug
         self._chip_type = None
-        self._device = SPIDevice(spi_bus, cs,
-                                 baudrate=8000000,
-                                 polarity=0, phase=0)
+        self._device = SPIDevice(spi_bus, cs, baudrate=8000000, polarity=0, phase=0)
         # init c.s.
         self._cs = cs
 
@@ -198,27 +196,46 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
             print("* Initializing DHCP")
         self._src_port = 68
         # Return IP assigned by DHCP
-        _dhcp_client = dhcp.DHCP(self, self.mac_address, response_timeout, debug=self._debug)
+        _dhcp_client = dhcp.DHCP(
+            self, self.mac_address, response_timeout, debug=self._debug
+        )
         ret = _dhcp_client.request_dhcp_lease()
         if ret == 1:
-            _ip = (_dhcp_client.local_ip[0], _dhcp_client.local_ip[1],
-                   _dhcp_client.local_ip[2], _dhcp_client.local_ip[3])
+            _ip = (
+                _dhcp_client.local_ip[0],
+                _dhcp_client.local_ip[1],
+                _dhcp_client.local_ip[2],
+                _dhcp_client.local_ip[3],
+            )
 
-            _subnet_mask = (_dhcp_client.subnet_mask[0], _dhcp_client.subnet_mask[1],
-                            _dhcp_client.subnet_mask[2], _dhcp_client.subnet_mask[3])
+            _subnet_mask = (
+                _dhcp_client.subnet_mask[0],
+                _dhcp_client.subnet_mask[1],
+                _dhcp_client.subnet_mask[2],
+                _dhcp_client.subnet_mask[3],
+            )
 
-            _gw_addr = (_dhcp_client.gateway_ip[0], _dhcp_client.gateway_ip[1],
-                        _dhcp_client.gateway_ip[2], _dhcp_client.gateway_ip[3])
+            _gw_addr = (
+                _dhcp_client.gateway_ip[0],
+                _dhcp_client.gateway_ip[1],
+                _dhcp_client.gateway_ip[2],
+                _dhcp_client.gateway_ip[3],
+            )
 
-            self._dns = (_dhcp_client.dns_server_ip[0], _dhcp_client.dns_server_ip[1],
-                         _dhcp_client.dns_server_ip[2], _dhcp_client.dns_server_ip[3])
-            self.ifconfig = ((_ip, _subnet_mask, _gw_addr, self._dns))
+            self._dns = (
+                _dhcp_client.dns_server_ip[0],
+                _dhcp_client.dns_server_ip[1],
+                _dhcp_client.dns_server_ip[2],
+                _dhcp_client.dns_server_ip[3],
+            )
+            self.ifconfig = (_ip, _subnet_mask, _gw_addr, self._dns)
             if self._debug:
                 print("* Found DHCP Server:")
-                print("IP: {}\nSubnet Mask: {}\nGW Addr: {}\nDNS Server: {}".format(_ip,
-                                                                                    _subnet_mask,
-                                                                                    _gw_addr,
-                                                                                    self._dns))
+                print(
+                    "IP: {}\nSubnet Mask: {}\nGW Addr: {}\nDNS Server: {}".format(
+                        _ip, _subnet_mask, _gw_addr, self._dns
+                    )
+                )
             self._src_port = 0
             return 0
         return -1
@@ -230,7 +247,7 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         if self._debug:
             print("* Get host by name")
         if isinstance(hostname, str):
-            hostname = bytes(hostname, 'utf-8')
+            hostname = bytes(hostname, "utf-8")
         self._src_port = int(time.monotonic())
         # Return IP assigned by DHCP
         _dns_client = dns.DNS(self, self._dns, debug=self._debug)
@@ -258,16 +275,16 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         """Returns the configured IP address."""
         return self.read(REG_SIPR, 0x00, 4)
 
-    def pretty_ip(self, ip): # pylint: disable=no-self-use, invalid-name
+    def pretty_ip(self, ip):  # pylint: disable=no-self-use, invalid-name
         """Converts a bytearray IP address to a
         dotted-quad string for printing
 
         """
         return "%d.%d.%d.%d" % (ip[0], ip[1], ip[2], ip[3])
 
-    def unpretty_ip(self, ip): # pylint: disable=no-self-use, invalid-name
+    def unpretty_ip(self, ip):  # pylint: disable=no-self-use, invalid-name
         """Converts a dotted-quad string to a bytearray IP address"""
-        octets = [int(x) for x in ip.split('.')]
+        octets = [int(x) for x in ip.split(".")]
         return bytes(octets)
 
     @property
@@ -283,13 +300,19 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         """
         self.write(REG_SHAR, 0x04, address)
 
-    def pretty_mac(self, mac): # pylint: disable=no-self-use, invalid-name
+    def pretty_mac(self, mac):  # pylint: disable=no-self-use, invalid-name
         """Converts a bytearray MAC address to a
         dotted-quad string for printing
 
         """
-        return "%s:%s:%s:%s:%s:%s" % (hex(mac[0]), hex(mac[1]), hex(mac[2]),
-                                      hex(mac[3]), hex(mac[4]), hex(mac[5]))
+        return "%s:%s:%s:%s:%s:%s" % (
+            hex(mac[0]),
+            hex(mac[1]),
+            hex(mac[2]),
+            hex(mac[3]),
+            hex(mac[4]),
+            hex(mac[5]),
+        )
 
     def remote_ip(self, socket_num):
         """Returns the IP address of the host who sent the current incoming packet.
@@ -299,7 +322,7 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         if socket_num >= self.max_sockets:
             return self._pbuff
         for octet in range(0, 4):
-            self._pbuff[octet] = self._read_socket(socket_num, REG_SNDIPR+octet)[0]
+            self._pbuff[octet] = self._read_socket(socket_num, REG_SNDIPR + octet)[0]
         return self.pretty_ip(self._pbuff)
 
     @property
@@ -320,8 +343,12 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
     @property
     def ifconfig(self):
         """Returns the network configuration as a tuple."""
-        return (self.ip_address, self.read(REG_SUBR, 0x00, 4),
-                self.read(REG_GAR, 0x00, 4), self._dns)
+        return (
+            self.ip_address,
+            self.read(REG_SUBR, 0x00, 4),
+            self.read(REG_GAR, 0x00, 4),
+            self._dns,
+        )
 
     @ifconfig.setter
     def ifconfig(self, params):
@@ -349,7 +376,7 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         if self.detect_w5500() == 1:
             # perform w5500 initialization
             for i in range(0, W5200_W5500_MAX_SOCK_NUM):
-                ctrl_byte = (0x0C + (i<<5))
+                ctrl_byte = 0x0C + (i << 5)
                 self.write(0x1E, ctrl_byte, 2)
                 self.write(0x1F, ctrl_byte, 2)
         else:
@@ -408,14 +435,14 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
 
         """
         with self._device as bus_device:
-            bus_device.write(bytes([addr >> 8])) # pylint: disable=no-member
-            bus_device.write(bytes([addr & 0xFF])) # pylint: disable=no-member
-            bus_device.write(bytes([callback])) # pylint: disable=no-member
+            bus_device.write(bytes([addr >> 8]))  # pylint: disable=no-member
+            bus_device.write(bytes([addr & 0xFF]))  # pylint: disable=no-member
+            bus_device.write(bytes([callback]))  # pylint: disable=no-member
             if buffer is None:
                 self._rxbuf = bytearray(length)
-                bus_device.readinto(self._rxbuf) # pylint: disable=no-member
+                bus_device.readinto(self._rxbuf)  # pylint: disable=no-member
                 return self._rxbuf
-            bus_device.readinto(buffer, end=length) # pylint: disable=no-member
+            bus_device.readinto(buffer, end=length)  # pylint: disable=no-member
             return buffer
 
     def write(self, addr, callback, data):
@@ -427,22 +454,22 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
 
         """
         with self._device as bus_device:
-            bus_device.write(bytes([addr >> 8])) # pylint: disable=no-member
-            bus_device.write(bytes([addr & 0xFF])) # pylint: disable=no-member
-            bus_device.write(bytes([callback])) # pylint: disable=no-member
+            bus_device.write(bytes([addr >> 8]))  # pylint: disable=no-member
+            bus_device.write(bytes([addr & 0xFF]))  # pylint: disable=no-member
+            bus_device.write(bytes([callback]))  # pylint: disable=no-member
 
-            if hasattr(data, 'from_bytes'):
-                bus_device.write(bytes([data])) # pylint: disable=no-member
+            if hasattr(data, "from_bytes"):
+                bus_device.write(bytes([data]))  # pylint: disable=no-member
             else:
                 for i, _ in enumerate(data):
-                    bus_device.write(bytes([data[i]])) # pylint: disable=no-member
+                    bus_device.write(bytes([data[i]]))  # pylint: disable=no-member
 
     # Socket-Register API
     def udp_remaining(self):
         """Returns amount of bytes remaining in a udp socket."""
         if self._debug:
-            print("* UDP Bytes Remaining: ", UDP_SOCK['bytes_remaining'])
-        return UDP_SOCK['bytes_remaining']
+            print("* UDP Bytes Remaining: ", UDP_SOCK["bytes_remaining"])
+        return UDP_SOCK["bytes_remaining"]
 
     def socket_available(self, socket_num, sock_type=SNMR_TCP):
         """Returns the amount of bytes to be read from the socket.
@@ -456,15 +483,15 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
 
         if sock_type == 0x02:
             # flush by reading remaining data from previous packet
-            while UDP_SOCK['bytes_remaining'] > 0 and self.socket_read(socket_num, 1):
+            while UDP_SOCK["bytes_remaining"] > 0 and self.socket_read(socket_num, 1):
                 if self._debug:
-                    print("Flushing {} bytes".format(UDP_SOCK['bytes_remaining']))
-                if UDP_SOCK['bytes_remaining'] > 0:
-                    UDP_SOCK['bytes_remaining'] = UDP_SOCK['bytes_remaining'] - 1
+                    print("Flushing {} bytes".format(UDP_SOCK["bytes_remaining"]))
+                if UDP_SOCK["bytes_remaining"] > 0:
+                    UDP_SOCK["bytes_remaining"] = UDP_SOCK["bytes_remaining"] - 1
 
         res = self._get_rx_rcv_size(socket_num)
 
-        res = int.from_bytes(res, 'b')
+        res = int.from_bytes(res, "b")
         if sock_type == SNMR_TCP:
             return res
         if res > 0:
@@ -473,12 +500,16 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
             # read the first 8 header bytes
             ret, self._pbuff = self.socket_read(socket_num, 8)
             if ret > 0:
-                UDP_SOCK['remote_ip'] = self._pbuff
-                UDP_SOCK['remote_port'] = self._pbuff[4]
-                UDP_SOCK['remote_port'] = (UDP_SOCK['remote_port'] << 8) + self._pbuff[5]
-                UDP_SOCK['bytes_remaining'] = self._pbuff[6]
-                UDP_SOCK['bytes_remaining'] = (UDP_SOCK['bytes_remaining'] << 8) + self._pbuff[7]
-                ret = UDP_SOCK['bytes_remaining']
+                UDP_SOCK["remote_ip"] = self._pbuff
+                UDP_SOCK["remote_port"] = self._pbuff[4]
+                UDP_SOCK["remote_port"] = (UDP_SOCK["remote_port"] << 8) + self._pbuff[
+                    5
+                ]
+                UDP_SOCK["bytes_remaining"] = self._pbuff[6]
+                UDP_SOCK["bytes_remaining"] = (
+                    UDP_SOCK["bytes_remaining"] << 8
+                ) + self._pbuff[7]
+                ret = UDP_SOCK["bytes_remaining"]
                 return ret
         return 0
 
@@ -498,12 +529,15 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         """
         assert self.link_status, "Ethernet cable disconnected!"
         if self._debug:
-            print("* w5k socket connect, protocol={}, port={}, ip={}".format(conn_mode, port,
-                                                                             self.pretty_ip(dest)))
+            print(
+                "* w5k socket connect, protocol={}, port={}, ip={}".format(
+                    conn_mode, port, self.pretty_ip(dest)
+                )
+            )
         # initialize a socket and set the mode
         res = self.socket_open(socket_num, conn_mode=conn_mode)
         if res == 1:
-            raise RuntimeError('Failed to initalize a connection with the socket.')
+            raise RuntimeError("Failed to initalize a connection with the socket.")
 
         # set socket destination IP and port
         self._write_sndipr(socket_num, dest)
@@ -517,14 +551,14 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
                 if self._debug:
                     print("SN_SR:", self.socket_status(socket_num)[0])
                 if self.socket_status(socket_num)[0] == SNSR_SOCK_CLOSED:
-                    raise RuntimeError('Failed to establish connection.')
+                    raise RuntimeError("Failed to establish connection.")
         elif conn_mode == SNMR_UDP:
-            UDP_SOCK['bytes_remaining'] = 0
+            UDP_SOCK["bytes_remaining"] = 0
         return 1
 
     def _send_socket_cmd(self, socket, cmd):
         self._write_sncr(socket, cmd)
-        while self._read_sncr(socket) != b'\x00':
+        while self._read_sncr(socket) != b"\x00":
             if self._debug:
                 print("waiting for sncr to clear...")
 
@@ -539,8 +573,11 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         sock = 0
         for _sock in range(len(sockets), self.max_sockets):
             status = self.socket_status(_sock)
-            if status[0] == SNSR_SOCK_CLOSED or status[0] == SNSR_SOCK_FIN_WAIT \
-               or status[0] == SNSR_SOCK_CLOSE_WAIT:
+            if (
+                status[0] == SNSR_SOCK_CLOSED
+                or status[0] == SNSR_SOCK_FIN_WAIT
+                or status[0] == SNSR_SOCK_CLOSE_WAIT
+            ):
                 sock = _sock
                 break
 
@@ -554,7 +591,7 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         """
         assert self.link_status, "Ethernet cable disconnected!"
         if self._debug:
-            print("*** Opening socket %d"%socket_num)
+            print("*** Opening socket %d" % socket_num)
         if self._read_snsr(socket_num)[0] == SNSR_SOCK_CLOSED:
             if self._debug:
                 print("* Opening W5k Socket, protocol={}".format(conn_mode))
@@ -572,9 +609,10 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
             # open socket
             self._write_sncr(socket_num, CMD_SOCK_OPEN)
             self._read_sncr(socket_num)
-            assert self._read_snsr((socket_num))[0] == 0x13 or \
-                 self._read_snsr((socket_num))[0] == 0x22, \
-                "Could not open socket in TCP or UDP mode."
+            assert (
+                self._read_snsr((socket_num))[0] == 0x13
+                or self._read_snsr((socket_num))[0] == 0x22
+            ), "Could not open socket in TCP or UDP mode."
             return 0
         return 1
 
@@ -602,15 +640,13 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
 
         # Check if there is data available on the socket
         ret = self._get_rx_rcv_size(socket_num)
-        ret = int.from_bytes(ret, 'b')
+        ret = int.from_bytes(ret, "b")
         if self._debug:
             print("Bytes avail. on sock: ", ret)
         if ret == 0:
             # no data on socket?
             status = self._read_snmr(socket_num)
-            if status in (SNSR_SOCK_LISTEN,
-                          SNSR_SOCK_CLOSED,
-                          SNSR_SOCK_CLOSE_WAIT):
+            if status in (SNSR_SOCK_LISTEN, SNSR_SOCK_CLOSED, SNSR_SOCK_CLOSE_WAIT):
                 # remote end closed its side of the connection, EOF state
                 ret = 0
                 resp = 0
@@ -624,12 +660,12 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
 
         if ret > 0:
             if self._debug:
-                print('\t * Processing {} bytes of data'.format(ret))
+                print("\t * Processing {} bytes of data".format(ret))
             # Read the starting save address of the received data
             ptr = self._read_snrx_rd(socket_num)
 
             # Read data from the starting address of snrx_rd
-            ctrl_byte = (0x18+(socket_num<<5))
+            ctrl_byte = 0x18 + (socket_num << 5)
 
             resp = self.read(ptr, ctrl_byte, ret)
 
@@ -646,17 +682,16 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
     def read_udp(self, socket_num, length):
         """Read UDP socket's remaining bytes.
         """
-        if UDP_SOCK['bytes_remaining'] > 0:
-            if UDP_SOCK['bytes_remaining'] <= length:
-                ret, resp = self.socket_read(socket_num, UDP_SOCK['bytes_remaining'])
+        if UDP_SOCK["bytes_remaining"] > 0:
+            if UDP_SOCK["bytes_remaining"] <= length:
+                ret, resp = self.socket_read(socket_num, UDP_SOCK["bytes_remaining"])
             else:
                 ret, resp = self.socket_read(socket_num, length)
             if ret > 0:
-                UDP_SOCK['bytes_remaining'] -= ret
+                UDP_SOCK["bytes_remaining"] -= ret
             return ret, resp
         return -1
 
-
     def socket_write(self, socket_num, buffer):
         """Writes a bytearray to a provided socket.
 
@@ -676,30 +711,31 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         while free_size < ret:
             free_size = self._get_tx_free_size(socket_num)
             status = self.socket_status(socket_num)
-            if status not in (SNSR_SOCK_ESTABLISHED,
-                              SNSR_SOCK_CLOSE_WAIT):
+            if status not in (SNSR_SOCK_ESTABLISHED, SNSR_SOCK_CLOSE_WAIT):
                 ret = 0
                 break
 
         # Read the starting address for saving the transmitting data.
         ptr = self._read_sntx_wr(socket_num)
         offset = ptr & 0x07FF
-        dst_addr = offset +  (socket_num * 2048 + 0x8000)
+        dst_addr = offset + (socket_num * 2048 + 0x8000)
 
         # update sn_tx_wr to the value + data size
         ptr += len(buffer)
         self._write_sntx_wr(socket_num, ptr)
 
-        cntl_byte = (0x14+(socket_num<<5))
+        cntl_byte = 0x14 + (socket_num << 5)
         self.write(dst_addr, cntl_byte, buffer)
 
         self._write_sncr(socket_num, CMD_SOCK_SEND)
         self._read_sncr(socket_num)
 
         # check data was  transferred correctly
-        while(self._read_socket(socket_num, REG_SNIR)[0] & SNIR_SEND_OK) != SNIR_SEND_OK:
+        while (
+            self._read_socket(socket_num, REG_SNIR)[0] & SNIR_SEND_OK
+        ) != SNIR_SEND_OK:
             if self.socket_status(socket_num) == SNSR_SOCK_CLOSED:
-                #self.socket_close(socket_num)
+                # self.socket_close(socket_num)
                 return 0
             time.sleep(0.01)
 
@@ -734,32 +770,30 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
 
     def _read_snrx_rd(self, sock):
         self._pbuff[0] = self._read_socket(sock, REG_SNRX_RD)[0]
-        self._pbuff[1] = self._read_socket(sock, REG_SNRX_RD+1)[0]
+        self._pbuff[1] = self._read_socket(sock, REG_SNRX_RD + 1)[0]
         return self._pbuff[0] << 8 | self._pbuff[1]
 
-
     def _write_snrx_rd(self, sock, data):
         self._write_socket(sock, REG_SNRX_RD, data >> 8)
-        self._write_socket(sock, REG_SNRX_RD+1, data & 0xff)
+        self._write_socket(sock, REG_SNRX_RD + 1, data & 0xFF)
 
     def _write_sntx_wr(self, sock, data):
         self._write_socket(sock, REG_SNTX_WR, data >> 8)
-        self._write_socket(sock, REG_SNTX_WR+1, data & 0xff)
+        self._write_socket(sock, REG_SNTX_WR + 1, data & 0xFF)
 
     def _read_sntx_wr(self, sock):
         self._pbuff[0] = self._read_socket(sock, 0x0024)[0]
-        self._pbuff[1] = self._read_socket(sock, 0x0024+1)[0]
+        self._pbuff[1] = self._read_socket(sock, 0x0024 + 1)[0]
         return self._pbuff[0] << 8 | self._pbuff[1]
 
-
     def _read_sntx_fsr(self, sock):
         data = self._read_socket(sock, REG_SNTX_FSR)
-        data += self._read_socket(sock, REG_SNTX_FSR+1)
+        data += self._read_socket(sock, REG_SNTX_FSR + 1)
         return data
 
     def _read_snrx_rsr(self, sock):
         data = self._read_socket(sock, REG_SNRX_RSR)
-        data += self._read_socket(sock, REG_SNRX_RSR+1)
+        data += self._read_socket(sock, REG_SNRX_RSR + 1)
         return data
 
     def _write_sndipr(self, sock, ip_addr):
@@ -767,14 +801,14 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
 
         """
         for octet in range(0, 4):
-            self._write_socket(sock, REG_SNDIPR+octet, ip_addr[octet])
+            self._write_socket(sock, REG_SNDIPR + octet, ip_addr[octet])
 
     def _write_sndport(self, sock, port):
         """Writes to socket destination port.
 
         """
         self._write_socket(sock, REG_SNDPORT, port >> 8)
-        self._write_socket(sock, REG_SNDPORT+1, port & 0xFF)
+        self._write_socket(sock, REG_SNDPORT + 1, port & 0xFF)
 
     def _read_snsr(self, sock):
         """Reads Socket n Status Register.
@@ -782,8 +816,6 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         """
         return self._read_socket(sock, REG_SNSR)
 
-
-
     def _write_snmr(self, sock, protocol):
         """Write to Socket n Mode Register.
 
@@ -799,7 +831,7 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         """Write to the socket port number.
         """
         self._write_socket(sock, REG_SNPORT, port >> 8)
-        self._write_socket(sock, REG_SNPORT+1, port & 0xFF)
+        self._write_socket(sock, REG_SNPORT + 1, port & 0xFF)
 
     def _write_sncr(self, sock, data):
         self._write_socket(sock, REG_SNCR, data)
@@ -814,7 +846,7 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
         """Write to a W5k socket register.
         """
         base = self._ch_base_msb << 8
-        cntl_byte = (sock<<5)+0x0C
+        cntl_byte = (sock << 5) + 0x0C
         if length is None:
             return self.write(base + sock * CH_SIZE + address, cntl_byte, data)
         return self.write(base + sock * CH_SIZE + address, cntl_byte, data)
@@ -822,5 +854,5 @@ class WIZNET5K: # pylint: disable=too-many-public-methods
     def _read_socket(self, sock, address):
         """Read a W5k socket register.
         """
-        cntl_byte = (sock<<5)+0x08
+        cntl_byte = (sock << 5) + 0x08
         return self.read(address, cntl_byte)
